HistoricalInteractiveBrokersClient

Struct HistoricalInteractiveBrokersClient 

pub struct HistoricalInteractiveBrokersClient { /* private fields */ }
Historical data client for Interactive Brokers.

This client provides methods for requesting historical bars and ticks for backtesting and research purposes.

Implementations

Source

impl HistoricalInteractiveBrokersClient

pub fn new( ib_client: Arc<Client>, instrument_provider: Arc<InteractiveBrokersInstrumentProvider>, ) -> Self

Create a new historical data client.

Arguments
  • ib_client - The IB API client
  • instrument_provider - The instrument provider
pub async fn request_bars( &self, bar_specifications: Vec<&str>, end_date_time: DateTime<Utc>, start_date_time: Option<DateTime<Utc>>, duration: Option<&str>, contracts: Option<Vec<Contract>>, instrument_ids: Option<Vec<InstrumentId>>, use_rth: bool, timeout: u64, ) -> Result<Vec<Bar>>

Request historical bars.

Arguments
  • bar_specifications - List of bar specifications (e.g., “1-HOUR-LAST”)
  • end_date_time - End date for bars
  • start_date_time - Optional start date
  • duration - Optional duration string (e.g., “1 D”)
  • contracts - List of IB contracts
  • instrument_ids - List of instrument IDs
  • use_rth - Use regular trading hours only
  • timeout - Request timeout in seconds
Errors

Returns an error if the request fails.

pub async fn request_ticks( &self, tick_type: &str, start_date_time: DateTime<Utc>, end_date_time: DateTime<Utc>, contracts: Option<Vec<Contract>>, instrument_ids: Option<Vec<InstrumentId>>, use_rth: bool, _timeout: u64, ) -> Result<Vec<Data>>

Request historical ticks with pagination support.

Arguments
  • tick_type - “TRADES” or “BID_ASK”
  • start_date_time - Start date
  • end_date_time - End date
  • contracts - List of IB contracts
  • instrument_ids - List of instrument IDs
  • use_rth - Use regular trading hours only
  • timeout - Request timeout in seconds
Errors

Returns an error if the request fails.

pub async fn request_instruments( &self, instrument_ids: Option<Vec<InstrumentId>>, contracts: Option<Vec<Contract>>, ) -> Result<Vec<InstrumentAny>>

Request instruments given instrument IDs or contracts.

This method uses the instrument provider to load and return instruments.

Arguments
  • instrument_ids - Optional list of instrument IDs
  • contracts - Optional list of IB contracts
Returns

Returns a list of instruments.

Errors

Returns an error if loading fails.